//  **** BEGIN LICENSE BLOCK ****
//  Copyright(c) 2005-2006 Adam Judson
//
//
//  PhotoMap
//  - display user contributed photos in a map
//
//  This program is free software; you can redistribute it and/or modify it under
//  the terms of the GNU General Public License as published by the Free
//  Software Foundation; either version 2 of the License, or (at your option)
//  any later version.
//
//  This program is distributed in the hope that it will be useful, but
//  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
//  or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
//  more details.
//
//  You should have received a copy of the GNU General Public License along with
//  this program; if not, write to the Free Software Foundation, Inc., 59 Temple
//  Place, Suite 330, Boston, MA 02111-1307 USA
//
//  **** END LICENSE BLOCK ****


// the wrapper for our specific map implementation
function PhotoMapMap(controller) {
   this.init(controller);
}

PhotoMapMap.prototype = {
   preferences : new PhotoMapPreferences(),

   init : function(controller) {
      this.controller = controller;
      this.type = this.preferences.getMapType();
      this.map = this.createMapImplementation();
      this.setupMap();
   },

   // not really happy with this factory, but it seems
   // like a waste to make it more complicated, as all the
   // implementations need to be included in the .xul file anyway
   createMapImplementation : function() {
      var map;
      if (this.type == "google") { 
         map = new PhotoMapGMap();
      } else if (this.type == "yahoo") {
         map = new PhotoMapYMap();
      } else {
         window.alert("Map type not implemented [" + this.type + "]");
      }
      return map;
   },

   setupMap : function() {
      if (this.map) {
         PhotoMapUtils.createMapSource(this.map.getURL(), this.map.getContent());
      }
   },
   
   createMap : function(iframe) {
      this.iframe = iframe;
      if (this.map) {
         this.map.setController(this);
         this.map.create(iframe);
         // somehow call this.map.ensureInit()
      }
   },

   setLocation : function(lat, lon, zoom) {
      if (this.map) {
         this.map.ensureInit();
         this.map.setLocation(lat, lon, zoom);
      } else {
         this.init(this.controller);
         this.createMap(this.iframe);
         var mmap = this;
         window.setTimeout(function() {PhotoMapMap.prototype.setLocation.call(mmap, lat, lon, zoom);}, 2000);
      }
   },

   getLocation : function() {
      if (this.map) {
         this.map.ensureInit();
         return this.map.getLocation();
      } else {
         return undefined;
      }
   },

   getBounds : function() {
      if (this.map) {
         this.map.ensureInit();
         return this.map.getBounds();
      } else {
         return undefined;
      }
   },

   mapMoved : function() {
      this.controller.mapMoved();
   },

   markerSelected : function(lat, lon) {
      this.controller.markerSelected(lat, lon);
   },

   addMarker : function(imgObj) {
      this.map.ensureInit();
      this.map.addMarker(imgObj);
   },

   clearMarkers : function() {
      this.map.clearMarkers();
   }
}
